@@ -1,5 +1,7 @@
 import codecs
+import json
 from argparse import ArgumentParser, Namespace
+from collections import OrderedDict
 from logging import Logger
 from pathlib import Path
 from shutil import copy2
@@ -34,7 +36,8 @@ def get_convert_ljs_to_generic_parser(parser: ArgumentParser):
 
 def convert_to_generic_ns(ns: Namespace, flogger: Logger, logger: Logger) -> bool:
   if ns.output_directory == ns.directory:
-    logger.error("Parameter 'directory' and 'output_directory': The two directories need to be distinct!")
+    logger.error(
+      "Parameter 'LJ-SPEECH-DIRECTORY' and 'OUTPUT-DIRECTORY': The two directories need to be distinct!")
     return False
 
   successful = convert_to_generic(ns.directory, ns.symlink, ns.n_digits,
@@ -48,6 +51,10 @@ def convert_to_generic(directory: Path, symlink: bool, n_digits: int, tier: str,
   accent_name = "North American"
   language = "eng"
   gender = GENDER_FEMALE
+  file_count = 13100
+  z_fill = len(str(file_count))
+
+  file_name_mapping = OrderedDict()
 
   speaker_dir_name = f"{speaker_name}{PARTS_SEP}{gender}{PARTS_SEP}{language}{PARTS_SEP}{accent_name}"
   speaker_dir_out_abs = output_directory / speaker_dir_name
@@ -64,6 +71,8 @@ def convert_to_generic(directory: Path, symlink: bool, n_digits: int, tier: str,
 
   lines_with_errors = 0
 
+  file_counter = 1
+
   # strip last empty line
   lines = metadata_content.strip().splitlines()
   for line_nr, line in enumerate(tqdm(lines, desc="Converting", unit=" file(s)"), start=1):
@@ -93,9 +102,11 @@ def convert_to_generic(directory: Path, symlink: bool, n_digits: int, tier: str,
     wav_file_in = directory / wav_file_relative
     assert wav_file_in.is_file()
 
-    stem_out = f"{speaker_dir_name};{wav_file_relative.stem}"
+    # stem_out = f"{speaker_dir_name};{wav_file_relative.stem}"
+    stem_out = str(file_counter).zfill(z_fill)
     wav_file_out = speaker_dir_out_abs / f"{stem_out}.wav"
     grid_file_out = speaker_dir_out_abs / f"{stem_out}.TextGrid"
+    file_counter += 1
 
     try:
       grid = create_grid(wav_file_in, text, tier, n_digits)
@@ -142,8 +153,27 @@ def convert_to_generic(directory: Path, symlink: bool, n_digits: int, tier: str,
         lines_with_errors += 1
         continue
 
+    hypothetical_grid_file_in = wav_file_in.parent / f"{wav_file_in.stem}.TextGrid"
+    file_name_mapping[str(grid_file_out.relative_to(
+      output_directory))] = str(hypothetical_grid_file_in.relative_to(directory))
+    file_name_mapping[str(wav_file_out.relative_to(
+      output_directory))] = str(wav_file_in.relative_to(directory))
+
   if lines_with_errors > 0:
     logger.warning(f"{lines_with_errors} lines couldn't be parsed!")
 
   all_successful = lines_with_errors == 0
+
+  file_name_mapping_json_path = output_directory / "filename-mapping.json"
+  try:
+    with open(file_name_mapping_json_path, mode="w", encoding="UTF-8") as f:
+      json.dump(file_name_mapping, f, indent=2)
+  except Exception as ex:
+    flogger.debug(ex)
+    flogger.error(
+      f"Mapping file \"{file_name_mapping_json_path.absolute()}\" couldn't be written!")
+    all_successful = False
+
+  logger.info(f"Saved output to: \"{output_directory.absolute()}\".")
+
   return all_successful
